==> kwave-0.7.11-1.tar.gz: kwave-0.7.11/libkwave/PluginContext.h <==
/***************************************************************************
        PluginContext.h  -  collects all references a plugin needs
                             -------------------
    begin                : Fri Jul 28 2000
    copyright            : (C) 2000 by Thomas Eschenbacher
    email                : Thomas.Eschenbacher@gmx.de
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef _PLUGIN_CONTEXT_H_
#define _PLUGIN_CONTEXT_H_

#include "config.h"

class KwaveApp;
class PluginManager;
class MenuManager;
class TopWidget;
class LabelManager;

class PluginContext
{
public:
    /** Constructor */
    PluginContext(
	KwaveApp      &app,
	PluginManager &plugin_mgr,
	LabelManager  *label_mgr,
	MenuManager   *menu_mgr,
	TopWidget     &topwidget,
	void *mod_handle,
	const QString &mod_name,
	const QString &mod_version,
	const QString &mod_author
    )
    :kwave_app(app),
    manager(plugin_mgr),
    label_manager(label_mgr),
    menu_manager(menu_mgr),
    top_widget(topwidget),
    handle(mod_handle),
    name(mod_name),
    version(mod_version),
    author(mod_author)
    {};

    KwaveApp      &kwave_app;
    PluginManager &manager;
    LabelManager  *label_manager;
    MenuManager   *menu_manager;
    TopWidget     &top_widget;

    void *handle;
    QString name;
    QString version;
    QString author;
};

#endif // _PLUGIN_CONTEXT_H_

/* end of libgui/PluginContext.h */

==> kwave_0.8.0.orig.tar.gz: kwave-0.8.0.orig/libkwave/PluginContext.h <==
/***************************************************************************
        PluginContext.h  -  collects all references a plugin needs
                             -------------------
    begin                : Fri Jul 28 2000
    copyright            : (C) 2000 by Thomas Eschenbacher
    email                : Thomas.Eschenbacher@gmx.de
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef _PLUGIN_CONTEXT_H_
#define _PLUGIN_CONTEXT_H_

#include "config.h"

class PluginManager;

class PluginContext
{
public:
    /** Constructor */
    PluginContext(
	PluginManager &plugin_mgr,
	void *mod_handle,
	const QString &mod_name,
	const QString &mod_version,
	const QString &mod_author
    )
        :m_plugin_manager(plugin_mgr),
         m_handle(mod_handle),
         m_name(mod_name),
         m_version(mod_version),
         m_author(mod_author)
    {};

    PluginManager &m_plugin_manager;

    void *m_handle;
    QString m_name;
    QString m_version;
    QString m_author;
};

#endif // _PLUGIN_CONTEXT_H_

/* end of libgui/PluginContext.h */
